import { Action, getModule, Module, MutationAction, VuexModule } from 'vuex-module-decorators';
import store from '@/store';
import http from '@/utils/request';
import { url } from '@/utils/url';
import { auth } from '@/store/modules/auth';
import { session } from '@/store/modules/session';

class OrderInInfo {
  amount?: any;
  sapFactoryCode?: any;
  materialCode?: any;
  sendSpot?: any;
  totalBackAmount?: any;
}

@Module({
  namespaced: true,
  dynamic: true,
  store,
  name: 'raw.handover.RUSreturning',
})
export class ReturningModule extends VuexModule {
  materielList: any[] = [];
  // 容器码
  ContainerCode: any = '';
  /**
   * 订单号查询结果
   */
  orderInInfo: OrderInInfo = new OrderInInfo();
  /**
   * 查询订单号
   * @param orderNo
   */
  @MutationAction
  async queryOrderInInfo(prdOrderFrom: string) {
    this.materielList = [];
    const { data }: any = await http.post(url.material.prdOrder.info, {
      prdOrderFrom,
      page: '1',
      rows: '50',
      loginName: session.loginName,
    });
    const materielList = data.map((item: any) => ({
      ...item,
      label: item.materialCode,
      value: item.materialCode,
      totalAmount: item.amount,
    }));
    const orderInInfo = data[0] || {};
    return { orderInInfo, materielList };
  }
  //根据时间查询单号列表
  @MutationAction
  async queryTimeInInfo(time: any) {
    this.materielList = [];
    const { data }: any = await http.post(url.material.prdOrder.info, {
      requireDateMin: time.requireDateMin,
      requireDateMax: time.requireDateMax,
      page: '1',
      rows: '50',
      loginName: session.loginName,
      prdOrderFuzzy: time.prdOrderFuzzy,
    });
    console.log('qqqqqqqqq', data);
    const materielList = data.map((item: any) => ({
      label: item.prdOrder,
      value: item.materialCode,
      amount: item.amount,
      wkposCode: item.wkposCode,
      sendSpot: item.sendSpot,
      totalBackAmount: item.totalBackAmount,
    }));
    const orderInInfo = data[0] || {};
    return { orderInInfo, materielList };
  }
  /**
   * 获取默认的工厂
   */
  @Action
  async queryDefaultFactoryCode() {
    const values: any = await http.post(url.auth.factory.sap, {
      factoryCode: session.factoryCode,
      loginName: session.loginName,
    });
    return values[0];
  }

  /**
   * 退料上传
   */
  @Action
  async tluSubmit(params: any) {
    console.log(params);
    await auth.checkPassword({
      factoryCode: session.factoryCode as string,
      loginName: params[0].operator,
      rfPwd: params[0].rfPwd,
    });
    await http.post(url.tl.uRussia, params);
    uni.showToast({
      //icon: "success",
      title: 'success',
      duration: 2000,
      image: '/static/icons/icon-51.png',
    });
  }
  @Action({ commit: 'updateCheckedOrderInInfoListKw' })
  async queryByFactoryCodeAndWorkAreaCode(content: any) {
    const res = await http.post('/wmspda/fg/queryByFactoryCodeAndWorkAreaCode', content);
    return res;
  }
  @MutationAction
  async searchBarcode(params: any) {
    const res: any = await http.post(url.auth.query.barcode, {
      factoryCode: session.factoryCode,
      loginName: session.loginName,
      barcode: params.barcode,
      productCode: params.productCode,
    });
    const ContainerCode = res.data;
    return { ContainerCode };
  }
}

export default getModule(ReturningModule);
